# Generated by Django 2.2.10 on 2020-03-05 13:36

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0004_auto_20200305_1848'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagewidget',
            name='slot',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='django_power_cms.TemplateSlot', verbose_name='Slot'),
        ),
    ]
