# Generated by Django 2.2.11 on 2020-03-08 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0008_auto_20200308_2150'),
    ]

    operations = [
        migrations.AddField(
            model_name='articledetailwidget',
            name='show_description',
            field=models.BooleanField(default=False, verbose_name='Show Description'),
        ),
    ]
