# Generated by Django 2.2.11 on 2020-03-08 14:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0009_articledetailwidget_show_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='author',
            field=models.CharField(blank=True, max_length=64, null=True, verbose_name='Author'),
        ),
        migrations.AddField(
            model_name='articledetailwidget',
            name='show_author',
            field=models.BooleanField(default=False, verbose_name='Show Author'),
        ),
        migrations.AlterField(
            model_name='articledetailwidget',
            name='show_published_time',
            field=models.BooleanField(default=True, verbose_name='Show Published Time'),
        ),
    ]
