# Generated by Django 2.2.11 on 2020-03-07 13:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0005_auto_20200305_2136'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='code',
            field=models.CharField(max_length=64, verbose_name='Code'),
        ),
        migrations.AlterUniqueTogether(
            name='page',
            unique_together={('site', 'code')},
        ),
    ]
