# Generated by Django 2.2.10 on 2020-03-05 07:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='articlelistwidget',
            name='article_list_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='django_power_cms.Page', verbose_name='Article List Page'),
        ),
        migrations.AddField(
            model_name='articlelistwidget',
            name='article_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='django_power_cms.Page', verbose_name='Article Page'),
        ),
    ]
