# Generated by Django 2.2.10 on 2020-03-05 10:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0003_template_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='app_label',
            field=models.CharField(blank=True, max_length=64, null=True, verbose_name='App Label'),
        ),
        migrations.AddField(
            model_name='theme',
            name='app_verbose_name',
            field=models.CharField(blank=True, max_length=64, null=True, verbose_name='App Verbose Name'),
        ),
        migrations.AddField(
            model_name='theme',
            name='code',
            field=models.CharField(default='', max_length=32, unique=True, verbose_name='Code'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='theme',
            name='preview_image',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='Preview Image'),
        ),
    ]
