<div class="power-widget-title">
    {% autoescape off %}{{title}}{% endautoescape %}
</div>
<div class="power-widget-body">
    {% autoescape off %}{{body}}{% endautoescape %}
</div>
<div class="power-widget-footer">
    {% autoescape off %}{{footer}}{% endautoescape %}
</div>