# Generated by Django 2.2.11 on 2020-03-19 04:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0013_auto_20200319_1039'),
    ]

    operations = [
        migrations.AddField(
            model_name='site',
            name='favicon',
            field=models.ImageField(blank=True, null=True, upload_to='site/favicons/', verbose_name='FavIcon'),
        ),
    ]
