# Generated by Django 2.2.11 on 2020-03-21 06:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0014_site_favicon'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='articles', to='django_power_cms.Site', verbose_name='Site'),
        ),
    ]
