# Generated by Django 2.2.11 on 2020-03-08 13:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0006_auto_20200307_2148'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='templateslot',
            options={'ordering': ['template', 'code'], 'verbose_name': 'Template Slots'},
        ),
        migrations.CreateModel(
            name='ArticleDetailWidget',
            fields=[
                ('widget_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='django_power_cms.Widget')),
                ('root', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_power_cms.Article', verbose_name='Root')),
            ],
            options={
                'verbose_name': 'Article Detail Widget',
                'verbose_name_plural': 'Article Detail Widgets',
            },
            bases=('django_power_cms.widget',),
        ),
    ]
