<!DOCTYPE html>
<html>{% load staticfiles %}
<head>
    <meta charset="utf-8">
    <meta content="IE=edge" http-equiv="X-UA-Compatible">
    <meta name="renderer" content="ie-stand">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
    <meta name="viewport" content="width=device-width,initial-scale=1.0,maximum-scale=1.0,user-scalable=0">
    <title>{{title}}</title>
    {% if site and site.favicon %}
    <link rel="icon" type="image/x-icon" href="{{site.favicon.url}}" />
    <link rel="shortcut icon" type="image/x-icon" href="{{site.favicon.url}}" />
    {% endif %}

    {% for css in css_links %}
    <link rel="stylesheet" type="text/css" href="{% static css %}" />
    {% endfor %}

    {% block header %}{% endblock %}
</head>
<body>
{% include "django-power-cms/templates/includes/page-style-fix.html" %}
{% block body %}{% endblock %}
{% for js in js_links %}
<script src="{% static js %}"></script>
{% endfor %}
</body>
</html>
