# Generated by Django 2.2.11 on 2020-03-19 02:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0012_auto_20200309_2121'),
    ]

    operations = [
        migrations.RenameField(
            model_name='topbarbrand',
            old_name='url',
            new_name='url_raw',
        ),
    ]
