from django_power_cms.apps import DjangoPowerCmsConfig
from django.utils.translation import ugettext_lazy as _

themes = [{
    "code": "7ce32fbb3d4b41dfbe592ba28487a175",
    "name": _("django2-style"),
    "app_label": "django_power_cms",
    "app_verbose_name": DjangoPowerCmsConfig.verbose_name,
    "description": _("Django2 style theme Description."),
    "preview_image": "django-power-cms/theme-preview-image/django2-style.png",
    "css": [
        "django-power-cms/themes/django2-style/css/django2-style.css",
    ],
    "js": [
        
    ]
}]
