# Generated by Django 2.2.11 on 2020-03-08 13:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0007_auto_20200308_2114'),
    ]

    operations = [
        migrations.AddField(
            model_name='articledetailwidget',
            name='show_prev_and_next_links',
            field=models.BooleanField(default=False, verbose_name='Show Prev&Next Links'),
        ),
        migrations.AddField(
            model_name='articledetailwidget',
            name='show_published_time',
            field=models.BooleanField(default=False, verbose_name='Show Published Time'),
        ),
    ]
