<table class="table">{% load i18n %}
<tr>
    <th>{% trans "Name" %}</th>
    <td>{{item.name}}</td>
</tr>
<tr>
    <th>{% trans "Code" %}</th>
    <td>{{item.code}}</td>
</tr>
<tr>
    <th>{% trans "Index Page Code" %}</th>
    <td>{{item.index_page_code}}</td>
</tr>
<tr>
    <th>{% trans "Published" %}</th>
    <td>{{item.published}}</td>
</tr>
</table>