# Generated by Django 2.2.10 on 2020-03-05 09:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0002_auto_20200305_1559'),
    ]

    operations = [
        migrations.AddField(
            model_name='template',
            name='code',
            field=models.CharField(default='', max_length=32, unique=True, verbose_name='Code'),
            preserve_default=False,
        ),
    ]
