# Generated by Django 2.2.11 on 2020-03-09 13:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_power_cms', '0011_auto_20200309_1735'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='templateslot',
            options={'ordering': ['template', 'order'], 'verbose_name': 'Template Slots'},
        ),
        migrations.AddField(
            model_name='templateslot',
            name='order',
            field=models.IntegerField(blank=True, null=True, verbose_name='Order'),
        ),
    ]
